@@ -62,7 +62,7 @@ module Net
     # Net::SSH.start for a description of each option.
     VALID_OPTIONS = [
       :auth_methods, :compression, :compression_level, :config, :encryption,
-      :forward_agent, :hmac, :host_key, :kex, :keys, :languages,
+      :forward_agent, :hmac, :host_key, :kex, :keys, :key_data, :languages,
       :logger, :paranoid, :password, :port, :proxy, :rekey_blocks_limit,
       :rekey_limit, :rekey_packet_limit, :timeout, :verbose,
       :global_known_hosts_file, :user_known_hosts_file, :host_key_alias,
@@ -123,6 +123,8 @@ module Net
     # * :kex => the key exchange algorithm (or algorithms) to use
     # * :keys => an array of file names of private keys to use for publickey
     #   and hostbased authentication
+    # * :key_data => an array of strings, with each element of the array being
+    #   a raw private key in PEM format.
     # * :logger => the logger instance to use when logging
     # * :paranoid => either true, false, or :very, specifying how strict
     #   host-key verification should be
@@ -153,13 +155,8 @@ module Net
         raise ArgumentError, "invalid option(s): #{invalid_options.join(', ')}"
       end
 
-      files = case options.fetch(:config, true)
-        when true then Net::SSH::Config.default_files
-        when false, nil then []
-        else Array(options[:config])
-        end
-      
-      options = Net::SSH::Config.for(host, files).merge(options)
+      options[:user] = user if user
+      options = configuration_for(host, options.fetch(:config, true)).merge(options)
       host = options.fetch(:host_name, host)
 
       if !options.key?(:logger)
@@ -195,5 +192,24 @@ module Net
         raise AuthenticationFailed, user
       end
     end
+
+    # Returns a hash of the configuration options for the given host, as read
+    # from the SSH configuration file(s). If +use_ssh_config+ is true (the
+    # default), this will load configuration from both ~/.ssh/config and
+    # /etc/ssh_config. If +use_ssh_config+ is nil or false, nothing will be
+    # loaded (and an empty hash returned). Otherwise, +use_ssh_config+ may
+    # be a file name (or array of file names) of SSH configuration file(s)
+    # to read.
+    #
+    # See Net::SSH::Config for the full description of all supported options.
+    def self.configuration_for(host, use_ssh_config=true)
+      files = case use_ssh_config
+        when true then Net::SSH::Config.default_files
+        when false, nil then return {}
+        else Array(use_ssh_config)
+        end
+      
+      Net::SSH::Config.for(host, files)
+    end
   end
-end
\ No newline at end of file
+end
