@@ -10,6 +10,11 @@ module Net; module SSH; module Transport
         8
       end
 
+      # Returns an arbitrary integer.
+      def iv_len
+        4
+      end
+
       # Does nothing. Returns self.
       def encrypt
         self
@@ -34,6 +39,16 @@ module Net; module SSH; module Transport
       def name
         "identity"
       end
+
+      # Does nothing. Returns nil.
+      def iv=(v)
+        nil
+      end
+
+      # Does nothing. Returns self.
+      def reset
+        self
+      end
     end
   end
 
