@@ -41,8 +41,17 @@ module Net; module SSH; module Transport
         info { "negotiating protocol version" }
 
         loop do
-          @version = socket.readline
-          break if @version.nil? || @version.match(/^SSH-/)
+          @version = ""
+          loop do
+            b = socket.recv(1)
+            
+            if b.nil?
+              raise Net::SSH::Disconnect, "connection closed by remote host"
+            end
+            @version << b
+            break if b == "\n"
+          end
+          break if @version.match(/^SSH-/)
           @header << @version
         end
 
@@ -55,6 +64,7 @@ module Net; module SSH; module Transport
 
         debug { "local is `#{PROTO_VERSION}'" }
         socket.write "#{PROTO_VERSION}\r\n"
+        socket.flush
       end
   end
-end; end; end
\ No newline at end of file
+end; end; end
